@@ -64,9 +64,8 @@ import org.apache.cxf.message.MessageUtils;
 import org.apache.cxf.service.model.EndpointInfo;
 import org.apache.cxf.transport.http.Address;
 import org.apache.cxf.transport.http.Headers;
-import org.apache.cxf.transport.http.URLConnectionHTTPConduit;
+import org.apache.cxf.transport.http.HttpClientHTTPConduit;
 import org.apache.cxf.transport.http.asyncclient.hc5.AsyncHTTPConduitFactory.UseAsyncPolicy;
-import org.apache.cxf.transport.http.asyncclient.hc5.AsyncHttpResponseWrapperFactory.AsyncHttpResponseWrapper;
 import org.apache.cxf.transport.https.HttpsURLConnectionInfo;
 import org.apache.cxf.transports.http.configuration.HTTPClientPolicy;
 import org.apache.cxf.version.Version;
@@ -98,15 +97,10 @@ import org.apache.hc.core5.util.Timeout;
 /**
  * Async HTTP Conduit using Apache HttpClient 5
  */
-public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
-    /**
-     * Enable HTTP/2 support
-     */
-    public static final String ENABLE_HTTP2 = "org.apache.cxf.transports.http2.enabled";
+public class AsyncHTTPConduit extends HttpClientHTTPConduit {
     public static final String USE_ASYNC = "use.async.http.conduit";
 
     private final AsyncHTTPConduitFactory factory;
-    private final AsyncHttpResponseWrapperFactory asyncHttpResponseWrapperFactory;
     private volatile int lastTlsHash = -1;
     private volatile Object sslState;
     private volatile URI sslURL;
@@ -118,7 +112,6 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
             throws IOException {
         super(b, ei, t);
         this.factory = factory;
-        this.asyncHttpResponseWrapperFactory = bus.getExtension(AsyncHttpResponseWrapperFactory.class);
     }
 
     public synchronized CloseableHttpAsyncClient getHttpAsyncClient(final TlsStrategy tlsStrategy)
@@ -144,9 +137,7 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
             super.setupConnection(message, address, csPolicy);
             return;
         }
-
-        propagateProtocolSettings(message, csPolicy);
-
+        propagateJaxwsSpecTimeoutSettings(message, csPolicy);
         boolean addressChanged = false;
         // need to do some clean up work on the URI address
         URI uri = address.getURI();
@@ -246,8 +237,8 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
 
         final RequestConfig.Builder b = RequestConfig
             .custom()
-            .setConnectTimeout(Timeout.ofMilliseconds(determineConnectionTimeout(message, csPolicy)))
-            .setResponseTimeout(Timeout.ofMilliseconds(determineReceiveTimeout(message, csPolicy)))
+            .setConnectTimeout(Timeout.ofMilliseconds(csPolicy.getConnectionTimeout()))
+            .setResponseTimeout(Timeout.ofMilliseconds(csPolicy.getReceiveTimeout()))
             .setConnectionRequestTimeout(Timeout.ofMilliseconds(csPolicy.getConnectionRequestTimeout()));
         
         final Proxy p = proxyFactory.createProxy(csPolicy, uri);
@@ -261,12 +252,14 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
         message.put(CXFHttpRequest.class, e);
     }
 
-    private void propagateProtocolSettings(Message message, HTTPClientPolicy csPolicy) {
-        if (message != null) {
-            final Object o = message.getContextualProperty(ENABLE_HTTP2);
-            if (o != null) {
-                csPolicy.setVersion("2.0");
-            }
+    private void propagateJaxwsSpecTimeoutSettings(Message message, HTTPClientPolicy csPolicy) {
+        int receiveTimeout = determineReceiveTimeout(message, csPolicy);
+        if (csPolicy.getReceiveTimeout() == 60000) {
+            csPolicy.setReceiveTimeout(receiveTimeout);
+        }
+        int connectionTimeout = determineConnectionTimeout(message, csPolicy);
+        if (csPolicy.getConnectionTimeout() == 30000) {
+            csPolicy.setConnectionTimeout(connectionTimeout);
         }
     }
 
@@ -432,16 +425,11 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
             }
             closed = true;
             if (!chunking && wrappedStream instanceof CachedOutputStream) {
-                try (CachedOutputStream out = (CachedOutputStream)wrappedStream) {
-                    this.basicEntity.setContentLength(out.size());
-                    wrappedStream = null;
-                    handleHeadersTrustCaching();
-                    // The wrappedStrem could be null for KNOWN_HTTP_VERBS_WITH_NO_CONTENT or empty
-                    // requests (org.apache.cxf.empty.request)
-                    if (wrappedStream != null) {
-                        out.writeCacheTo(wrappedStream);
-                    }
-                }
+                CachedOutputStream out = (CachedOutputStream)wrappedStream;
+                this.basicEntity.setContentLength(out.size());
+                wrappedStream = null;
+                handleHeadersTrustCaching();
+                out.writeCacheTo(wrappedStream);
             }
             super.close();
         }
@@ -487,8 +475,8 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
             if (connectionFuture != null) {
                 return;
             }
-            
-            final CXFResponseCallback delegate = new CXFResponseCallback() {
+
+            CXFResponseCallback responseCallback = new CXFResponseCallback() {
                 @Override
                 public void responseReceived(HttpResponse response) {
                     setHttpResponse(response);
@@ -496,20 +484,6 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
 
             };
 
-            CXFResponseCallback responseCallback = delegate;
-            if (asyncHttpResponseWrapperFactory != null) {
-                final AsyncHttpResponseWrapper wrapper = asyncHttpResponseWrapperFactory.create();
-                if (wrapper != null) {
-                    responseCallback = new CXFResponseCallback() {
-                        @Override
-                        public void responseReceived(HttpResponse response) {
-                            wrapper.responseReceived(response, delegate::responseReceived);
-                        }
-                    };
-                }
-            }
-
-
             FutureCallback<Boolean> callback = new FutureCallback<Boolean>() {
 
                 public void completed(Boolean result) {
@@ -616,7 +590,7 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
             final HttpAsyncClient c = getHttpAsyncClient(tlsStrategy);
             final Credentials creds = (Credentials)outMessage.getContextualProperty(Credentials.class.getName());
             if (creds != null) {
-                credsProvider.setCredentials(new AuthScope(url.getHost(), url.getPort()), creds);
+                credsProvider.setCredentials(new AnyAuthScope(), creds);
                 ctx.setUserToken(creds.getUserPrincipal());
             }
             @SuppressWarnings("unchecked")
@@ -709,10 +683,7 @@ public class AsyncHTTPConduit extends URLConnectionHTTPConduit {
         }
 
         protected void handleResponseAsync() throws IOException {
-            // The response hasn't been handled yet, should be handled asynchronously
-            if (httpResponse == null) {
-                isAsync = true;
-            }
+            isAsync = true;
         }
 
         protected void closeInputStream() throws IOException {
